三傻大闹宝莱坞 (豆瓣)
Description: 三傻大闹宝莱坞电影简介和剧情介绍,三傻大闹宝莱坞影评、图片、预告片、影讯、论坛、在线购票
Keywords: 三傻大闹宝莱坞,3 Idiots,三傻大闹宝莱坞影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.14豆瓣电影Top250

# 三傻大闹宝莱坞 3 Idiots (2009)

更新描述或海报

导演: 拉吉库马尔·希拉尼
编剧: 维德胡·维诺德·乔普拉 / 拉吉库马尔·希拉尼 / 阿希贾特·乔希
主演: 阿米尔·汗 / 卡琳娜·卡普尔 / 马达范 / 沙尔曼·乔希 / 奥米·瓦依达 / 博曼·伊拉尼 / 莫娜·辛格 / 拉杰夫·拉宾德拉纳特安
类型: 剧情 / 喜剧 / 爱情 / 歌舞
制片国家/地区: 印度
语言: 印地语 / 乌尔都语 / 英语
上映日期: 2011-12-08(中国大陆) / 2009-12-25(印度)
片长: 171分钟(印度)
又名: 三个傻瓜(台) / 作死不离3兄弟(港) / 三个白痴 / 三个傻蛋 / 三个呆瓜 / 三生万悟 / 寻找兰彻 / Three Idiots
IMDb: tt1187043
豆瓣评分
引用
9.2
1777915人评价
5星
68.8%
4星
25.6%
3星
4.9%
2星
0.5%
1星
0.2%
好友评分
你关注的人看过这部作品的平均分
6.4
5人评价
好于 99% 喜剧片
好于 99% 剧情片
我看过这部电影 2020-07-12 修改
我的评价:
推荐

## 三傻大闹宝莱坞的剧情简介 · · · · · ·

本片根据印度畅销书作家奇坦·巴哈特（Chetan Bhagat）的处女作小说《五点人》（Five Point Someone）改编而成。法兰（马德哈万 R Madhavan 饰）、拉杜（沙曼·乔希 Sharman Joshi 饰）与兰乔（阿米尔·汗 Aamir Khan 饰）是皇家工程学院的学生，三人共居一室，结为好友。在以严格著称的学院里，兰乔是个非常与众不同的学生，他不死记硬背，甚至还公然顶撞校长“病毒”（波曼·伊拉尼 Boman Irani 饰），质疑他的教学方法。他不仅鼓动法兰与拉杜去勇敢追寻理想，还劝说校长的二女儿碧雅（卡琳娜·卡普 Kareena Kapoor 饰）离开满眼铜臭的未婚夫。兰乔的特立独行引起了模范学生“消音器”（奥米·维嘉 Omi Vaidya 饰）的不满，他约定十年后再与兰乔一决高下，看哪种生活方式更能取得成功。
本片获孟... (展开全部) 本片根据印度畅销书作家奇坦·巴哈特（Chetan Bhagat）的处女作小说《五点人》（Five Point Someone）改编而成。法兰（马德哈万 R Madhavan 饰）、拉杜（沙曼·乔希 Sharman Joshi 饰）与兰乔（阿米尔·汗 Aamir Khan 饰）是皇家工程学院的学生，三人共居一室，结为好友。在以严格著称的学院里，兰乔是个非常与众不同的学生，他不死记硬背，甚至还公然顶撞校长“病毒”（波曼·伊拉尼 Boman Irani 饰），质疑他的教学方法。他不仅鼓动法兰与拉杜去勇敢追寻理想，还劝说校长的二女儿碧雅（卡琳娜·卡普 Kareena Kapoor 饰）离开满眼铜臭的未婚夫。兰乔的特立独行引起了模范学生“消音器”（奥米·维嘉 Omi Vaidya 饰）的不满，他约定十年后再与兰乔一决高下，看哪种生活方式更能取得成功。
本片获孟买电影博览奖最佳影片、最佳导演、最佳配角（波曼·伊拉尼）、最佳剧本等六项大奖，并获国际印度电影协会最佳影片、最佳导演、最佳剧情、最佳摄影等十六项大奖。 ©豆瓣

## 三傻大闹宝莱坞的演职员 · · · · · · ( 全部 19 )

- 拉吉库马尔·希拉尼 导演
- 阿米尔·汗 饰 兰彻 'Rancho' Shamaldas Chanchad
- 卡琳娜·卡普尔 饰 皮娅 Pia
- 马达范 饰 法汗 Farhan Qureshi
- 沙尔曼·乔希 饰 拉朱 Raju Rastogi
- 奥米·瓦依达 饰 Chatur 'Silencer' Ramalingam

## 三傻大闹宝莱坞的视频和图片 · · · · · · ( 预告片3 | 添加视频评论 | 图片679 · 添加 )

## 三傻大闹宝莱坞的获奖情况 · · · · · · ( 全部 )

- 第37届日本电影学院奖
- 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  肖申克的救赎

  阿甘正传

  当幸福来敲门

  摔跤吧！爸爸

  贫民窟的百万富翁

  国王的演讲

  心灵捕手

  美丽心灵

  中国合伙人

  死亡诗社

我要写短评

## 三傻大闹宝莱坞的短评 · · · · · · ( 全部 353245 条 )

热门 / 最新 / 好友

### 7028 有用 私喜 看过 2010-08-07 00:00:41

看了这部电影是我2010年最幸运的一件事 力荐！

### 4853 有用 Piper 看过 2010-08-06 00:06:27

【温馨提示：请忽略这傻逼名字.不然你会错过一部好电影】1、病毒的鸟巢飞来了一只自由之鸟；2、Ta有没有告诉你,朋友就是给你一枚硬币教你自己独立做出选择的那个人.这个人才是你最大的财富 ：）

### 1908 有用 Lan~die 看过 2010-08-08 22:45:01

如果有一天你变成了奇怪的家伙，生活于恐惧和虚假之中，就念重生的咒语“All is well”，狠狠地给这个世界一脚！对鼓励别样人生价值和给人梦想的片子我是举双手赞成，何况从头到尾都拍得这么欢乐。台词：“朋友是男人最大的胸部”、“你这么害怕明天，又怎么能过好今天”。

### 4550 有用 少年 遊 看过 2010-08-05 11:44:57

这几个月来看过的最好的片——”做自己“，也许才是人生终极的成功。别总嘲笑印度人”阿三“，他们已经追上来了，无论经济、科技还是我们一贯认为只会跳舞唱歌的宝莱坞电影。盛赞！5+1星！

### 4280 有用 玲珑 看过 2010-08-04 18:46:54

当你不断追求卓越，成功就会不知不觉追赶你。害怕明天，怎能过好今天呢？心很脆弱，我们要学会哄它。鸡不会知道蛋的前程。学习是为了完善人生，而非享乐人生。只为生命而感激。朋友失败，你难过，朋友成功，你更难过。一切顺利。

> 更多短评 353245条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 黑烟的圈 看过 2020-08-13 11:29:36

印度人的偏见就那么容易被改变吗？包容性那么强，不会吧，不会吧，这电影一定是在开玩笑吧？

我要写影评

## 三傻大闹宝莱坞的影评 · · · · · · ( 全部 5105 条 )

热门 / 最新 / 好友
艾小柯 2010-08-20 09:05:38

## 那一场关于理想的美梦

我最喜欢的一位单口相声表演者叫Russell Peters，他是加拿大第二代印度移民，专长于种族笑话，又善模仿各种族裔的口音，不管是中国人、印度人还是意大利人，他都能找到突出特色予以模仿夸张，在逗得观众哈哈大笑之余留下悠远回味，一边佩服他观察细致入微，一边咂摸各个种族的... (展开)
4519 271 351回应 收起
意识变态 2010-08-20 23:48:25

## Aal izz well------《三傻大闹宝莱坞》VS《人在囧途》

这篇影评可能有剧透

有识之士路过请原谅我把这两部电影放在一起比较，事情的起因是前几天我向别人推荐了一部除了名字翻译得恶俗，内容却属上乘的印度电影佳作《三傻大闹宝莱坞（three idiots）》，结果居然被贬成还不如《人在囧途》，对于此人的艺术欣赏水平我只能用影片里的一句话形容——剧... (展开)
3744 249 514回应 收起
To三儿 2010-08-05 17:41:13

## 三傻大闹宝莱坞3 Idiots 经典台词

“他的人和名字一样不同寻常” “一出生就有人告诉我们，生活是场赛跑，不跑快点就会惨遭蹂躏，哪怕是出生，我们都得和3亿个精子赛跑” “一切顺利，一切顺利……” “盐水具有极强的导电性，初二物理知识，我们都学过，只有他会应用。” “噪鹃从来不自己筑巢，他只在别人... (展开)
2499 120 310回应 收起
巴斯特德 2010-08-29 16:42:47

## 如果有十星，我想给十星；如果有一百个星，我就给一百个！

All is well！ 口音很重的英语，听久了，却能给人会心的微笑。 当我们的导演都在铺张大场面，玩特技的时候，看看印度，这个一度，甚至现在，都被我们嘲笑的国家，这个落后，贫穷，拥挤的国家，生产出了怎样的艺术，生产出了怎样的激动人心的作品。 让我们看看这部电影颂扬了什... (展开)
2917 244 362回应 收起
°葫芦娃你站住 2010-08-06 00:41:47

## 长命百岁不敌半世痛快

我很想说豆瓣你真没眼光。亦或是眼光太高。让我羞于写影评的人都要为它写些什么赞颂一番。 　　 　　两个小时的片长，无半点拖沓的就把故事轻松的讲完了，有喜有泪，故事简单道理易懂，可升华到片中人物的境界怕是要活个三五十年尝尽人间冷暖才能领悟到。如果说这个世界太浮... (展开)
861 102 209回应 收起
夏笳 2011-01-05 11:40:44

## 梦醒之后是现实

梦醒之后是现实 ——Three Idiots 叙事分析与意识形态批评 2009年上映的印度电影Three Idiots（又名《三傻大闹宝莱坞》、《三个傻蛋》、《寻找兰彻》，由拉库马•希拉尼（Rajkumar Hirani）执导，改编自印度畅销书作家奇坦•巴哈特（Chetan Bhagat... (展开)
625 46 116回应 收起
付玲 2010-09-21 20:00:20

## 理想主义者的意淫

前几天在看一篇关于1992年美国共和党和民主党竞选的文章，其中提到这么一句话：虚构般美好的事情，只能在虚构的媒介中达成。说的是共和党提倡的家庭观念导致选票下滑，以至于败给民主党的事情。不免在论述中提到政治概念隐性灌输的方式，其中最行之有效又不容易引起抵触心理的... (展开)
863 595 488回应 收起
常减常肥的温绮 2011-01-24 11:31:55

## 政府只是把它建了起来，然后就撒手不管了——电影《三个傻瓜》外的印度理工学院（转载自南方周末）

“我就是因为考不上印度理工，才到麻省理工来的。”一位美国麻省理工学院的印度学生在开学时这样回答教授的提问，当时，教授看到新生里有一位来自印度，好奇地问：“你怎么会在这里？你的国家有印度理工学院，为什么不去那里呢？” 这是在印度理工学院的校友中广为流... (展开)
364 21 31回应 收起
背兔子的乌龟 2017-05-07 10:46:01

## 校长“病毒”其实是个好人

校长病毒可以定义为好人，他儿子进他们学校都被拒绝三次。 他不是不想让他儿子进，他非常希望他儿子能进去，可惜考不上，没办法的事。 他其实也有权利让他儿子进去，身为校长它却没有这么做，如果在XX国，压根不会这样。 他精力旺盛，老当益壮吧，不偏不倚、 双手写字、休息时... (展开)
274 18 35回应 收起
卢十四 2012-12-09 03:34:42

## 励志和意淫间的金线

《三傻》是一部励志片。励志片的正道是树立正面典型。这个正面典型需要充实丰满，神完气足。惟其如此，才能充满感染力，激励人心。 但不幸的是，此片虽然热闹非凡，精彩纷呈，却惟独在塑造人物上交出了一只做工不甚精良的充气娃娃。 兰乔一出场，就设计令跋扈学长遭遇电鸡。... (展开)
271 202 55回应 收起

> 更多影评 5105篇

添加新讨论

## 讨论区 · · · · · ·

看过 | 来自重影 |  | 2022-11-22 22:17:56
搞笑 | 来自Lly |  | 2022-11-22 22:15:34
你们真的看懂了吗？ | 来自剪刀、石头、布 | 2 回应 | 2022-11-19 23:16:25
校长为什么不让自己的儿子顶替别人上大学？ | 来自星星点灯 | 29 回应 | 2022-11-19 01:27:13
这个导演也太敢拍了吧 | 来自步瓯 | 4 回应 | 2022-11-18 01:20:19

> 去这部影片的讨论区（全部836条）

## 关于《三傻大闹宝莱坞》的问题 · · · · · · ( 全部35个 )

- 如果你第一次看印度电影，9分。如果你第十次看，每次都歌舞升平，拉扯情节，你会给几分？ 4人回答
- 电影最后这段的拍摄地是在哪？ 16人回答

> 全部35个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 腾讯视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

## 谁在看这部电影 · · · · · ·

- BENNY
  刚刚 看过
- 微信用户
  刚刚 看过
- Guofy
  1分钟前 看过

3197803人看过 / 242745人想看

订阅三傻大闹宝莱坞的评论:
feed: rss 2.0